Citing scikit-survival
======================

If you are using **scikit-survival** in your scientific research,
please cite the following paper:

    S. Pölsterl, "scikit-survival: A Library for Time-to-Event Analysis Built on Top of scikit-learn,"
    Journal of Machine Learning Research, vol. 21, no. 212, pp. 1–6, 2020.

BibTeX entry::

    @article{sksurv,
      author  = {Sebastian P{\"o}lsterl},
      title   = {scikit-survival: A Library for Time-to-Event Analysis Built on Top of scikit-learn},
      journal = {Journal of Machine Learning Research},
      year    = {2020},
      volume  = {21},
      number  = {212},
      pages   = {1-6},
      url     = {http://jmlr.org/papers/v21/20-729.html}
    }
